@@ -104,12 +104,12 @@ if ($do==1) {
                "\n\n";
          &Net::FullAuto::FA_Core::cleanup;
       }
+      print "\nInstalling Microsoft IIS Web Server . . .\n\n";
       # http://www.iis.net/learn/install/installing-iis-85/
       #      installing-iis-85-on-windows-server-2012-r2
       # https://technet.microsoft.com/en-us/library/hh831475.aspx
       # http://twiki.org/cgi-bin/view/TWiki/TWikiOnWindowsIISCygwin
       # https://www.iis.net/configreference/system.webserver/fastcgi
-      print "\n   Installing Microsoft IIS Web Server . . .\n\n";
       ($stdout,$stderr)=$handle->cmd("DISM.EXE /enable-feature /all ".
          "/online /featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
          "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
@@ -150,9 +150,11 @@ if ($do==1) {
       ($stdout,$stderr)=$handle->cwd($appcmd);
       ($stdout,$stderr)=$handle->cmd("pwd",'__display__');
       my $sleep=0;
-      while (!(-e "./appcmd.exe")) {
-         sleep 2;
-         last if $sleep++>300;
+      while (1==1) {
+        my $ls_output=$handle->cmd("ls -1");
+        last if -1<index $ls_output,'appcmd.exe';
+        sleep 2;
+        last if $sleep++>300;
       }
       ($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
          "/id:2 /physicalPath:$cygloc\\root /bindings:http/*:5000",
@@ -161,15 +163,17 @@ if ($do==1) {
          "system.webServer/fastCgi /+[\"fullpath=\'$cygloc\\script\\".
          "CGI_script\',arguments=\'$cygloc\\script\\fullautoapi_fastcgi.pl ".
          "-e\',maxInstances=\'4\',idleTimeout=\'300\',activityTimeout=\'30\',".
-         "requestTimeout=\'90\',instanceMaxRequests=\'1000\',protocol=".
+         "requestTimeout='\90\',instanceMaxRequests=\'1000\',protocol=".
          "\'NamedPipe\',flushNamedPipe=\'False\']\" /commit:apphost",
          '__display__');
       ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
-         "system.webServer/handlers /+\"[name=\'FullAutoAPI\',path=".
-         "\'*\',verb=\'GET,HEAD,POST\',modules=\'FastCgiModule\',".
-         "scriptProcessor=\'$cygloc\\script\\CGI_Script|$cygloc\\".
-         "script\\fullautoapi_fastcgi.pl -e\',resourceType=\'Unspecified\',".
-         "requireAccess=\'Script\']\" /commit:apphost",'__display__');
+         "system.webServer/handlers /+\"[name=\'FullAutoAPI\',".
+         "path=\'*\',verb=\'GET,HEAD,POST\',modules=".
+         "\'FastCgiModule\',scriptProcessor=\'$cygloc\\script\\".
+         "CGI_Script|$cygloc\\script\\fullautoapi_fastcgi.pl -e\',". 
+         "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
+         "/commit:apphost",'__display__');
+      ($stdout,$stderr)=$handle->cwd("~/FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("touch CGI_Script");
       #
       # echo-ing/streaming files over ssh can be tricky. Use echo -e
@@ -187,7 +191,6 @@ if ($do==1) {
 cd bin
 /bin/perl -wT \\x241
 END
-      ($stdout,$stderr)=$handle->cwd("~/FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script");
       ($stdout,$stderr)=$handle->cwd("~");
       #($stdout,$stderr)=$handle->cmd("iisreset /start",'__display__');
@@ -1682,7 +1685,7 @@ END
        '            status_msg => %SQ%Password Expired%SQ%%NL%'.
        '        }));%NL%'.
        '        $c->detach;%NL%'.
-       '    }%NL%';
+       '    }%NL%'.
        '}%NL%';
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/index : Private/i$ad\' ./Root.pm");
